@@ -8,7 +8,9 @@ def vine_download(url, output_dir = '.', merge = True, info_only = False):
     html = get_html(url)
     
     title = r1(r'<meta property="og:title" content="([^"]*)"', html)
-    url = "http:" + r1(r'<source src="([^"]*)"', html)
+    url = r1(r'<source src="([^"]*)"', html)
+    if url[0:2] == "//":
+        url = "http:" + url
     type, ext, size = url_info(url)
     
     print_info(site_info, title, type, size)
